import i18next from "i18next";
import { acquire as fetchTuitioData } from "@flare/tuitio-client";

const getHeaders = (): HeadersInit => {
  const { token } = fetchTuitioData();
  const language = i18next.language;

  const headers: HeadersInit = {
    "Content-Type": "application/json"
  };

  if (token) {
    headers.Authorization = `Tuitio ${token}`;
  }

  if (language) {
    headers["Accept-Language"] = language;
  }

  return headers;
};

const fetcher = (url: string) => fetch(url, { method: "GET", headers: getHeaders() }).then(res => res.json());

async function mutationFetcher<Command>(url: string, { arg }: { arg: Command }) {
  const hasBody = arg !== undefined && arg !== null;
  const headers = getHeaders();
  const body = hasBody ? JSON.stringify(arg) : undefined;

  return fetch(url, {
    method: "POST",
    headers,
    body
  }).then(res => res.json());
}

// async function deleteFetcher<Command>(url: string, { arg }: { arg: Command }) {
//   return fetch(combine(url, arg as number), {
//     method: "DELETE",
//     headers: getHeaders()
//   }).then(res => res.json());
// }

export { fetcher, mutationFetcher };
